# <img src="https://raw.githubusercontent.com/BuStudios/StashConnect/main/assets/icon.png" height="22"> StashConnect

An API wrapper for [stashcat](https://stashcat.com/) and [schul.cloud](https://schul.cloud).<br>
```bash
pip install stashconnect
```

## Contributors
- All code made by [BuStudios](https://github.com/bustudios)
- Create a pull request to contribute code yourself

## Version 0.7.5
#### To be added:
- [x] fix links
- [ ] returnable file object
- [ ] bot file for easy bot setup

---
StashConnect is not affiliated with Stashcat GmbH or any of its affiliates.

<img src="https://raw.githubusercontent.com/BuStudios/StashConnect/main/assets/icon-full.png">